collect() executes the query and retrieves the results into a local tibble.
This brings all the data from the database into R's memory, which is useful
once you've done as much as possible in the database, and now need to use
R functions.
Usage
# S3 method for class 'tbl_sql'
collect(
x,
...,
n = Inf,
warn_incomplete = TRUE,
sql_options = NULL,
cte = deprecated()
)Arguments
- x
A lazy data frame backed by a database query.
- ...
Ignored.
- n
Number of rows to fetch. Defaults to
Inf, meaning all rows.- warn_incomplete
Warn if
nis less than the number of result rows?- sql_options
SQL rendering options generated by
sql_options().- cte